#ifndef HEAD_FILE
#define HEAD_FILE 1

#include <MLV/MLV_all.h>
#include <string.h>
#include "annexe.h"

#define BASE_TREEFILES 20

/*
Cette structure permet de représenter un fichier (d=0) ou un dossier (d=1)
Elle contient :
- Son nom (char *name)
- Sa Taille (weight)
- La liste de tous les fichiers / dossiers contenu si celui-ci est un dossier (MyFile **ls)
- D'autres informations 'techniques' comme nb_ls, max_ls, pos et hover servant à gérer l'affichage et la mémoire
*/
typedef struct MyFile MyFile;
struct MyFile
{
	char *name;
	int d;
	int weight;
	int nb_ls;
	int max_ls;
	MyFile **ls;
	MyFile *up;
	
	//Affichages
	int pos[2];
	int hover;
};


/* Cette structure permet de regrouper plusieurs informations
-liées à l'affichage comme hover, baseX, baseY.. (explorateur de fichiers)
-liées à ce qu'on veut récupérer (selected contient le nom du fichier pour le chargement/sauvegarde)
*/
typedef struct MyFile_Data MyFile_Data;
struct MyFile_Data
{
	char *Home_Directory;
	char *selected;
	int method;
	int hover;
	int baseX;
	int baseY;
	int nb_min;
	int plus[2];
};

#define FILE_SCREEN_WIDTH MLV_get_window_width()
#define FILE_SCREEN_HEIGHT MLV_get_window_height()



int MyFile_SauvFile(char *text);
/*
	Permet de sauvegarder une chaîne de caractère dans un fichier.
	Le choix du fichier sera choisi par l'utilisateur grâce à l'explorateur de fichier de MyFile.
	ARGS :
		- char *text : Chaîne de caractère à enregistrer
	RETURN :
		- 0 : La sauvegarde a échoué
		- 1 : la sauvegarde a réussi
*/


char *MyFile_ChargFile(void);
/*
	Permet de charger le contenu d'un fichier dans une chaîne de caractère.
	Le choix du fichier sera choisi par l'utilisateur grâce à l'explorateur de fichier de MyFile.
	RETURN :
		- NULL : Le chargement a échoué
		- Une chaîne de caractère allouée dynamiquement qu'il faudra donc désalloué.
*/


void MyFile_Init(void);
/* 
	Permet de Charger le module d'explorateur de fichier MyFile
	Impératif avant d'utiliser n'importe qu'elle autre fontion MyFile_*
*/


void MyFile_Quit();
/*	
	Permet de quitter 'proprement' le module MyFile
*/



/*** Fonctions de développements de MyFile *********/
MyFile *MyFile_Alloc(char *name);
/*
	Permet d'allouer la structure MyFile pour le dossier en cours.
	RETURN :
		- NULL si échoué
		- Une structure MyFile
*/


MyFile *MyFile_PartialAlloc(char *name, MyFile *top);
/*
	Permet d'allouer seulement une partie de la structure MyFile (utile pour les sous-dossiers ou fichiers.
	RETURN :
		- NULL si échoué
		- Une structure MyFile partiellement allouée.
*/


void MyFile_Free(MyFile *temp);
/*
	Permet de libérer la mémoire d'une structure MyFile
*/


int MyFile_AddLs(MyFile *temp, char name[], int d, int weight);
/*
	Permet d'ajouter un fichier / sous-dossier dans la liste des éléments du dossier en cours.
	ARGS :
		- MyFile *temp : La structure MyFile du dossier en cours
		- char name[] : Le nom du fichier / sous-dossier
		- int d : (1) pour un dossier, (0) pour un fichier
		- int weight : Poids en octet du fichier
	RETURN :
		- 0 : échoué
		- 1 : reussi
*/


void MyFile_DevTrFile(char *temp);
/*
	Transformer sur place la chaine de caractère 'temp' en le chemin du dossier supérieur
	ARGS :
		- char *temp : La chaîne à modifier
*/

int MyFile_RecupName(FILE *f, char *name);
/*
	Récupére le nom du fichier / sous-dossier à partir d'un ls -R enregistré dans 'f' et le place dans 'name'.
*/


MyFile *MyFile_Generate(char d[]);
/*
	Crée une structure MyFile et la remplie. Génère donc la liste des sous-dossiers / fichiers (noms, taille, ...) ainsi que le nom du dossier supérieur.
	ARGS :
		- char d[] : Le chemin du répertoir à analyser
	RETURN :
		- NULL si échoué
		- Structure MyFile si réussie
*/


void MyFile_AffConsole(MyFile *temp);
/*
	Permet un affichage rudimentaire d'une structure MyFile en console.
	ARGS :
		- MyFile *temp : La structure MyFile à afficher
*/


/* Fonctions de dessins pour afficher le dessin d'un dossier / fichier et d'une croix cerclée. */
MLV_Image *draw_directory(void);
MLV_Image *draw_file(void);
MLV_Image *draw_plus(void);


char *MyFile_ConvertWeight(int weight);
/*
	Convertie une taille en octet et renvoie une chaine de caractère de la forme : "1Go" ou "13Mo" ou "999Ko" ou "1 o"
	ARGS :
		- int weight : Une taille en octet.
	RETURN :
		- char * : Une chaîne de caractère allouée dynamiquement qu'il faudra désallouer.
*/


void MyFile_AffWindow(MyFile *temp, int baseX, int baseY);
/*
	Affichage l'explorateur de fichier de MyFile.
	ARGS :
		- MyFile *temp : La structure MyFile du dossier à afficher.
		- int baseX : La position en X à partir de laquelle afficher l'explorateur.
		- int baseY : La position en Y à partir de laquelle afficher l'explorateur.
*/


int MyFile_ListEvent(MyFile *current);
/*
	Permet de gérer les événements liés à l'explorateur de fichier MyFile.
	ARGS :
		- MyFile *current : La structure MyFile du dossier à afficher.
	RETURN :
		- (-1) : Arrêt de la boucle des événements
		- (0) : Aucun action effectuée : On Continue la boucle
		- (1) : Des actions ont été faites mais on continue la boucle.
*/


int MyFile_DirectOk(char *name);
/*
	Vérifie si un dossier pointé par le chemin 'name' fait partie du dossier personnel de l'utilisateur.
	ARGS :
		- char *name : Chemin du dossier à tester.
	RETURN :
		- 1 : Le dossier fait partie du dossier personnel de l'utilisateur
		- 0 : Le dossier n'en fait pas partie.
*/

#endif
