#ifndef HEAD_MENU
#define HEAD_MENU

#include <MLV/MLV_all.h>
#include <string.h>
#include <time.h>

// Nombre maximal de boutons affichages
#define MAX_BUTTONS 100
#define VERSION 0.1


#include "score.h"
#include "jeu.h"
#include "test.h"
#include "file.h"

#define SCREEN_WIDTH jeu->width
#define SCREEN_HEIGHT jeu->height

/*
	Cette structure permet la représentation en mémoire d'un bouton :
		-int x,y : Position x et y
		-int height, width : Hauteur et Largeur
		-char *value : Texte se trouvant dans le bouton
		-MLV_Font *font : Couleur du Texte
		-int (*function)() : Fonction à Executer si on Clique sur le bouton
		-hover, padding, borderActive,anim : variables locales
*/
typedef struct Button Button;
struct Button
{
	int x;
	int y;
	int height;
	int width;
	char *value;
	MLV_Font *font;
	int (*function)();
	int hover;
	int padding;
	int borderActive;
	int anim;
};

/*
	Cette structure permet de garder la liste des boutons affichés à l'écran.
	Elle est constitué d'un tableau fixe de pointeurs vers la structure Bouton, ainsi que du nombre de boutons et de la largeur maximale des boutons.
*/
typedef struct ButtonList ButtonList;
struct ButtonList
{
	Button *tab[MAX_BUTTONS];
	int nb;
	int max_width;
};

/*
	Cette structure ne sert qu'au chargement à partir d'un fichier d'une partie.
	Une fois un fichier jeu chargé, cette structure est renvoyée contenant toutes informations
	essentielles pour redémarrer la partie : liste des prochains jetons, liste des jetons joués, pseudo, temps restants, score...
*/
typedef struct PartieCharg PartieCharg;
struct PartieCharg
{
	TokenList *jetons_coming;
	TokenList *jetons;
	char pseudo[100];
	int points;
	int time;
	int gameMode;
};


ButtonList *ButtonList_Init(void);
/*
	Permet d'allouer une structure ButtonList.
	RETURN :
		- NULL si échoué
		- Une structure ButtonList vide si réussi
*/


void ButtonList_FreeAll(ButtonList **lst);
/*
	Permet de libérer la mémoire de tous les boutons présents à l'écran ainsi que de la strucutre ButtonList.
	ARG :
		- ButtonList **lst : La structure ButtonList à free.
*/


int ButtonList_AddButton(ButtonList *lst, int x, int y, int padding, const char text[], MLV_Font *font, int (*function)());
/*
	Permet d'ajouter à une structure ButtonList un nouveau bouton.
	ARGS :
		- ButtonList *lst : La structure ButtonList à modifier
		- int x : Position en x
		- int y : Position en y
		- int padding : Espacement intérieur
		- const char text[] : Contenu du bouton
		- MLV_Font *font : Police de Caractère du bouton
		- int (*function)() : Fonction à executer au clic du bouton
	RETURN :
		- 1 si réussi
		- 0 si échec
*/


void ButtonList_AnimButtons(ButtonList *lst);
/*
	Permet d'activer l'animation de tous les boutons
	ARGS :
		- ButtonList *lst : La structure ButtonList des boutons à animer
*/


void ButtonList_AffAll(ButtonList *lst);
/*
	Permet d'afficher à l'écran tous les boutons.
	ARGS :
		- ButtonList *lst : La structure ButtonList des boutons à afficher
*/


PartieCharg charger_une_partie(void);
/*
	Permet de charger à partir d'un fichier une partie.
	RETURN :
		- Si échec (fichier introuvable ou non conforme au jeu) : Une structure PartieCharg vide (jetons_coming = NULL, ...)
		- Si réussi : Une Structure PartieCharg contenant les éléments nécessaire au chargement de la partie
*/


int sauvegarder_une_partie(TokenList *jetons_coming, TokenList *jetons, const char pseudo[], int points, int time);
/*
	Permet de sauvegarder dans un fichier à partir des données en mémoire du jeu une partie.
	ARGS :
		- TokenList *jetons_coming : Les jetons à venir
		- TokenList *jetons : Les jetons du plateau
		- const char pseudo[] : Pseudo du joueur
		- int points : Score en cours
		- int time : Temp restant
	RETURN :
		- 1 si réussi
		- 0 si échec
*/


int ButtonList_Event(ButtonList *lst);
/*
	Permet de gérer les événements liés aux boutons affichés (hover, clic).
	ARGS :
		- ButtonList *lst : Structure ButtonList des boutons affichés
	RETURN :
		- -1 si on doit arrêter la boucle principale
		- 0 si on doit continuer et qu'aucune action n'a été faite
		- 1 si on doit continuer et qu'une / plusieurs action(s) ont été faites.
*/


void draw_titleMain(const char font_str[], const char title[], int taille, ButtonList *lst);
/*
	Permet d'afficher le titre du jeu.
*/


void draw_text_center(const char font_str[], const char title[], int taille, int h);
/*
	Permet d'afficher un texte centrer horizontalement par rapport à l'écran.
	ARGS :
		- const char font_str[] : chemin vers la police de caractère
		- const char title[] : texte à afficher
		- int taille : Taille de la police
		- int h : Position Y
*/


/* Fonction de Développement */
Button *Button_Init(int x, int y, int padding, const char text[], MLV_Font *font, void *function);
/*
	Permet d'allouer la place pour une structure Button et de l'initialiser
*/


void Button_Free(Button **temp);
/*
	Permet de libérer la mémoire d'une structure Button
*/


void Button_Aff(Button *temp);
/*
	Permet d'afficher une structure Button individuellement.
*/


int CaracInStr(char c, char str[]);
/*
	Permet de vérifier si un caractère 'c' se trouve dans une chaine 'str'.
*/


int Sauv_Partie(void);
/*
	Fonction passerelle, voir "sauvegarder_une_partie"
*/


int Load_Partie(void);
/*
	Fonction passerelle, voire "charger_une_partie"
*/


int classement(void);
/*
	Permet de charger et d'afficher le classement
*/


int classement2(void);
/*
	Idem que classement mais légèrement modifié pour être utiliser au cours d'une partie
*/

int classement_reinit(void);
/*
	Permet de réinitialiser le classemenet ainsi que le fichier de sauvegarde du classement. (Supprime tous les scores enregistrés).
*/

int options(void);
/*
	Permet d'afficher les options du jeu
*/

int jouer(void);
/*
	Permet d'accéder au panneau du lancement du jeu et de créer une partie.
*/

int retour_au_bureau(void);
/*
	Permet de revenir au bureau (Fonction à utiliser uniquement dans le cadre des ButtonList)
*/

int Jeu_Edit_Avatar(void);
/*
	Lancer l'éditeur d'avatar
*/

int Menu_Lancer(void);
/*
	Affiche le menu principal du jeu
*/

/* Génère les MLV_Image nécessaire à l'affiche d'élements du menu */
MLV_Image *fleche_droite(int hover);
MLV_Image *fleche_gauche(int hover);
MLV_Image *Create_ModeBasic(void);
MLV_Image *Create_ModeAnim(void);
MLV_Image *Menu_ConstrucFond(int seed, int type);
void Menu_affFond(int baseX, int baseY, int maxX, int maxY);
void Menu_AffVersion(void);
MLV_Image *MLV_Image_Difficulty_Button(Difficulty dif, int width, int height);























#endif
